@@ -6,6 +6,7 @@
 #' The network map can be plotted using internal R routines or using \href{http://www.vosviewer.com/}{VOSviewer} by Nees Jan van Eck and Ludo Waltman.
 #' @param NetMatrix is a network matrix obtained by the function \code{\link{biblioNetwork}}. 
 #' @param n is an integer. It indicates the number of vertices to plot.
+#' @param Degree is an integer. It idicates the min frequency of a vertex. If Degree is not NULL, n is ignored.
 #' @param type is a character object. It indicates the network map layout:
 #' 
 #' \tabular{lll}{
@@ -23,6 +24,14 @@
 #' @param remove.isolates is logical. If TRUE isolates vertices are not plotted.
 #' @param remove.multiple is logical. If TRUE multiple links are plotted using just one edge.
 #' @param labelsize is an integer. It indicates the label size in the plot. Default is \code{labelsize=1}
+#' @param halo is logical. If TRUE communities are plotted using different colors. Default is \code{halo=FALSE}
+#' @param cluster is a character. It indicates the type of cluster to perform among ("null", optimal", "lovain","infomap","edge_betweenness","walktrap").
+#' @param curved is a logical. If TRUE edges are plotted with an optimal curvature. Default is \code{curved=FALSE}
+#' @param weighted This argument specifies whether to create a weighted graph from an adjacency matrix. 
+#' If it is NULL then an unweighted graph is created and the elements of the adjacency matrix gives the number of edges between the vertices. 
+#' If it is a character constant then for every non-zero matrix entry an edge is created and the value of the entry is added as an edge attribute 
+#' named by the weighted argument. If it is TRUE then a weighted graph is created and the name of the edge attribute will be weight.
+#' @param edgesize is an integer. It indicates the network edge size.
 #' @return It is a network object of the class \code{igraph}.
 #' 
 #' @examples
@@ -40,12 +49,12 @@
 #' @seealso \code{\link{biblioAnalysis}} to perform a bibliometric analysis.
 #' 
 #' @export
-networkPlot<-function(NetMatrix, n=20,Title="Plot", type="kamada", labelsize=1, vos.path=NULL, size=FALSE, noloops=TRUE, remove.multiple=TRUE,remove.isolates=FALSE){
+networkPlot<-function(NetMatrix, n=NULL, Degree=NULL, Title="Plot", type="kamada", labelsize=1, halo=FALSE, cluster="walktrap", vos.path=NULL, size=FALSE, curved=FALSE, noloops=TRUE, remove.multiple=TRUE,remove.isolates=FALSE,weighted=NULL,edgesize=1){
 
 NET=NetMatrix
 
 # Create igraph object
-bsk.network <- graph.adjacency(NET,mode="undirected")
+bsk.network <- graph.adjacency(NET,mode="undirected",weighted=weighted)
 V(bsk.network)$id <- colnames(NET)
 
 # Compute node degrees (#links) and use that to set node size:
@@ -54,6 +63,10 @@ if (isTRUE(size)){V(bsk.network)$size <- (deg/max(deg)[1])*20}
 else{V(bsk.network)$size=rep(5,length(V(bsk.network)))}
 
 # Select number of vertices to plot
+if (!is.null(Degree)){
+  n=length(which(diag(NET)>=Degree))
+}
+
 if (n>dim(NET)[1]) {n <- dim(NET)[1]}
 NetDegree <- unname(sort(deg,decreasing=TRUE)[n])
 bsk.network <- delete.vertices(bsk.network,which(degree(bsk.network)<NetDegree))
@@ -88,11 +101,40 @@ switch(type,
 
 if (type!="vosviewer"){
   
-  net_groups <- cluster_walktrap(bsk.network)
-  V(bsk.network)$color <- brewer.pal(12, 'Set3')[membership(net_groups)]
+  switch(cluster,
+         null={V(bsk.network)$color="#8DD3C7"},
+         optimal={
+           net_groups <- cluster_optimal(bsk.network)
+           V(bsk.network)$color <- brewer.pal(12, 'Set3')[membership(net_groups)]},
+         louvain={
+           net_groups <- cluster_louvain(bsk.network)
+           V(bsk.network)$color <- brewer.pal(12, 'Set3')[membership(net_groups)]},
+         infomap={
+           net_groups <- cluster_infomap(bsk.network)
+           V(bsk.network)$color <- brewer.pal(12, 'Set3')[membership(net_groups)]},
+         edge_betweenness={
+           net_groups <- cluster_edge_betweenness(bsk.network)
+           V(bsk.network)$color <- brewer.pal(12, 'Set3')[membership(net_groups)]},
+         walktrap={
+           net_groups <- cluster_walktrap(bsk.network)
+           V(bsk.network)$color <- brewer.pal(12, 'Set3')[membership(net_groups)]}
+         )
+  
 ## Plot the network
   
-plot(bsk.network,layout = l, vertex.label.dist = 0.4, vertex.frame.color = 'black', vertex.label.color = 'black', vertex.label.font = 1, vertex.label = V(bsk.network)$name, vertex.label.cex = labelsize, main=Title)}
+  if (!is.null(weighted)){
+    E(bsk.network)$width <- (E(bsk.network)$weight + min(E(bsk.network)$weight))/max(E(bsk.network)$weight + min(E(bsk.network)$weight)) *edgesize
+  } else {E(bsk.network)$width=edgesize}
+  
+
+  if (isTRUE(halo) & cluster!="null"){
+    plot(net_groups,bsk.network,layout = l, edge.curved=curved, vertex.label.dist = 0.4, vertex.frame.color = 'black', vertex.label.color = 'black', vertex.label.font = 1, vertex.label = V(bsk.network)$name, vertex.label.cex = labelsize, main=Title)
+  } else{
+    plot(bsk.network,layout = l, edge.curved=curved, vertex.label.dist = 0.4, vertex.frame.color = 'black', vertex.label.color = 'black', vertex.label.font = 1, vertex.label = V(bsk.network)$name, vertex.label.cex = labelsize, main=Title)
+  }
+
+}  
+
 
 return(bsk.network)}
 
